@@ -42,7 +42,7 @@ class AssetManager:
         complete_asset_path = self.make_asset_path_complete( asset_path )
         return complete_asset_path.is_file()
 
-    def load( self, asset_path : Path ) -> ( Any, ReloadStatus ):
+    def load( self, asset_path : Path ) -> ReloadingAsset:
         absolute_asset_path = self.make_asset_path_complete( asset_path )
         assert self.exists( absolute_asset_path ), f'Could not load asset. File path: "{asset_path}"'
         asset_loader = self.get_asset_loader_for_file( asset_path )
@@ -51,5 +51,5 @@ class AssetManager:
             file_path = absolute_asset_path
         )
         self.assets.append(reloading_asset)
-        load_status = reloading_asset.try_reload()
-        return reloading_asset, load_status
+        reloading_asset.try_reload()
+        return reloading_asset
