@@ -16,7 +16,7 @@ class Game:
         self.game_window = game_window
 
     def update( self, dt ):
-        glClearColor( 1, 1, 1, 1.0 )
+        glClearColor( _r(), 1, 1, 1.0 )
 
     def draw( self ):
         ...
